AnchorScrollController class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
animateTo(double offset, {required Duration duration, required Curve curve})
→ Future<void>
-
Animates the position from its current value to the given value.
inherited
-
animateToIndex(int index, {Duration delayedDuration = const Duration(milliseconds: 1), Duration animateDuration = const Duration(milliseconds: 10), double ruleOutSpacing = 0, Curve curve = Curves.linear})
→ Future<void>
-
跳转至指定 index
delayedDuration和animateDuration一起为总的跳转时间
-
attach(ScrollPosition position)
→ void
-
Register the given position with this controller.
inherited
-
createScrollPosition(ScrollPhysics physics, ScrollContext context, ScrollPosition? oldPosition)
→ ScrollPosition
-
Creates a ScrollPosition for use by a Scrollable widget.
inherited
-
debugFillDescription(List<String> description)
→ void
-
Add additional information to the given description for use by toString.
inherited
-
detach(ScrollPosition position)
→ void
-
Unregister the given position with this controller.
inherited
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
jumpTo(double value)
→ void
-
Jumps the scroll position from its current value to the given value,
without animation, and without checking if the new value is in range.
inherited
-
jumpToIndex(int index, {Duration duration = const Duration(microseconds: 1), double ruleOutSpacing = 0})
→ Future<void>
-
跳转至指定 index
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited