GlobalOptions class

Constructors

GlobalOptions()
factory

Properties

bottomSheetOptions BottomSheetOptions
no setter
cupertinoModalPopupOptions CupertinoModalPopupOptions
no setter
dialogOptions DialogOptions
no setter
eventBus EventBus
no setter
no setter
globalRefreshFooter Footer
getter/setter pair
globalRefreshHeader Header
getter/setter pair
globalScaffoldMessengerKey GlobalKey<ScaffoldMessengerState>?
no setter
hashCode int
The hash code for this object.
no setterinherited
loadingOptions LoadingOptions
no setter
logCrossLine bool
no setter
modalWindowsOptions ModalWindowsOptions
no setter
pushStyle RoutePushStyle
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldWillPop bool
no setter
schedulerBinding SchedulerBinding
getter/setter pair
toastOptions ToastOptions
no setter
wheelOptions WheelOptions
no setter
widgetsBinding WidgetsBinding
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBottomSheetOptions(BottomSheetOptions options) → void
设置全局 BottomSheet 配置 Set the global BottomSheet configuration
setCupertinoModalPopupOptions(CupertinoModalPopupOptions options) → void
设置全局 CupertinoBottomSheet 配置 Set the global BottomSheet configuration
setDialogOptions(DialogOptions options) → void
设置全局 DialogOptions 配置 Set the global DialogOptions configuration
setGlobalNavigatorKey(GlobalKey<NavigatorState> navigatorKey) → void
设置全局 NavigatorKey Set the global NavigatorKey
setGlobalPushMode(RoutePushStyle style) → void
设置全局路由跳转样式 Set the global route push style
setGlobalScaffoldMessengerKey(GlobalKey<ScaffoldMessengerState> scaffoldMessengerKey) → void
设置全局 ScaffoldMessengerKey Set the global ScaffoldMessengerKey
setLoadingOptions(LoadingOptions options) → void
设置全局 LoadingOptions 配置 Set the global LoadingOptions configuration
setLogCrossLine(bool has) → void
setModalWindowsOptions(ModalWindowsOptions modalWindowsOptions) → void
设置全局 ModalWindowsOptions 配置 Set the global ModalWindowsOptions 配置
setScaffoldWillPop(bool value) → void
setToastOptions(ToastOptions options) → void
设置全局 ToastOptions 配置 Set the global ToastOptions configuration
setWheelOptions(WheelOptions options) → void
设置全局 ListWheel 配置 Set the global ListWheel configuration
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited