GlobalWayUI class

Constructors

GlobalWayUI()
factory

Properties

bottomSheetOptions BottomSheetOptions
设置全局 BottomSheet 配置 Set the global BottomSheet configuration
getter/setter pair
cupertinoModalPopupOptions CupertinoModalPopupOptions
设置全局 CupertinoBottomSheet 配置 Set the global BottomSheet configuration
getter/setter pair
dialogOptions DialogOptions
设置全局 DialogOptions 配置 Set the global DialogOptions configuration
getter/setter pair
eventBus EventBus
final
globalRefreshFooter Footer
getter/setter pair
globalRefreshHeader Header
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loadingOptions LoadingOptions
设置全局 LoadingOptions 配置 Set the global LoadingOptions configuration
getter/setter pair
logCrossLine bool
getter/setter pair
modalWindowsOptions ModalWindowsOptions
设置全局 ModalWindowsOptions 配置 Set the global ModalWindowsOptions 配置
getter/setter pair
设置全局 NavigatorKey Set the global NavigatorKey
getter/setter pair
pushStyle RoutePushStyle
设置全局路由跳转样式 Set the global route push style
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaffoldMessengerKey GlobalKey<ScaffoldMessengerState>
设置全局 ScaffoldMessengerKey Set the global ScaffoldMessengerKey
getter/setter pair
schedulerBinding SchedulerBinding
getter/setter pair
toastOptions ToastOptions
设置全局 ToastOptions 配置 Set the global ToastOptions configuration
getter/setter pair
wheelOptions WheelOptions
设置全局 ListWheel 配置 Set the global ListWheel configuration
getter/setter pair
widgetsBinding WidgetsBinding
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited