SliverPinnedPersistentHeaderElement class

Inheritance
Available extensions

Properties

accessibleNavigation bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

accessibleNavigation → bool 用户是否使用TalkBack或VoiceOver等辅助功能服务与应用程序进行交互。
no setter
boldText bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

alwaysUse24HourFormat → bool 格式化时间时是否使用24小时格式。
no setter
bottomNavigationBarHeight double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

获取导航栏高度
no setter
buildScope BuildScope
A BuildScope whose dirty Elements can only be rebuilt by BuildOwner.buildScope calls whose context argument is an Element within this BuildScope.
no setterinherited
canRequestFocus bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

no setter
child Element?
getter/setter pair
debugDoingBuild bool
Whether the widget is currently updating the widget or render tree.
no setterinherited
debugIsActive bool
Returns true if the Element is active.
no setterinherited
debugIsDefunct bool
Returns true if the Element is defunct.
no setterinherited
depth int
An integer that is guaranteed to be greater than the parent's, if any. The element at the root of the tree must have a depth greater than 0.
no setterinherited
deviceHeight double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

手机屏幕高
no setter
devicePixelRatio double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

devicePixelRatio → double 单位逻辑像素的设备像素数量,即设备像素比。这个数字可能不是2的幂,实际上它甚至也可能不是整数。例如,Nexus 6的设备像素比为3.5。
no setter
deviceSize Size

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

size → Size 设备尺寸信息,如屏幕的大小,单位 pixels
no setter
deviceWidth double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

手机屏幕的宽
no setter
dirty bool
Returns true if the element has been marked as needing rebuilding.
no setterinherited
disableAnimations bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

disableAnimations → bool 平台是否要求尽可能禁用或减少使用动画。
no setter
focusScope FocusScopeNode

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

FocusScope
no setter
getRenderBox RenderBox?

Available on BuildContext, provided by the ExtensionContext extension

no setter
getWidgetBounds Rect

Available on BuildContext, provided by the ExtensionContext extension

get Widget Bounds (width, height, left, top, right, bottom and so on).Widgets must be rendered completely. 获取widget Rect
no setter
hasFocus bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasPrimaryFocus bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

no setter
height double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

The same of MediaQuery.of(context).size.height Note: updates when you rezise your screen (like on a browser or desktop window)
no setter
heightPixel double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

手机屏幕高分辨率
no setter
iconButtonTheme IconButtonThemeData

Available on BuildContext, provided by the ExtensionContext extension

no setter
iconColor Color?

Available on BuildContext, provided by the ExtensionContext extension

give access to Theme.of(context).iconTheme.color
no setter
iconTheme IconThemeData

Available on BuildContext, provided by the ExtensionContext extension

no setter
invertColors bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

invertColors → bool 设备是否反转平台的颜色
no setter
isDarkMode bool

Available on BuildContext, provided by the ExtensionContext extension

Check if dark mode theme is enable
no setter
isFirstFocus bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

no setter
isLandscape bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

check if device is on landscape mode
no setter
isLargeTablet bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

True if the shortestSide is largest than 720p
no setter
isPhone bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

True if the shortestSide is smaller than 600p
no setter
isPortrait bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

check if device is on portrait mode
no setter
isSmallTablet bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

True if the shortestSide is largest than 600p
no setter
isTablet bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

True if the current device is Tablet
no setter
maybeOverlay OverlayState?

Available on BuildContext, provided by the ExtensionContext extension

no setter
maybeView FlutterView?

Available on BuildContext, provided by the ExtensionContext extension

Returns the FlutterView that the provided context will render into.
no setter
mediaQuery MediaQueryData

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

similar to MediaQuery.of(context).padding
no setter
mediaQueryShortestSide double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

get the shortestSide from screen
no setter
mediaQuerySize Size

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

The same of MediaQuery.of(context).size
no setter
mounted bool
Whether the Widget this context is associated with is currently mounted in the widget tree.
no setterinherited

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

NavigatorState
no setter
nearestScope FocusScopeNode

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

no setter
orientation Orientation

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

orientation → Orientation 屏幕方向(横向/纵向)
no setter
overlay OverlayState?

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

overlay
no setter
overlay OverlayState?

Available on BuildContext, provided by the ExtensionContext extension

no setter
owner BuildOwner?
The object that manages the lifecycle of this element.
no setterinherited
padding EdgeInsets

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

padding → EdgeInsets 显示器的部分被系统UI部分遮挡,通常由硬件显示“凹槽”或系统状态栏
no setter
parent FocusNode?

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

no setter
platformBrightness Brightness

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

platformBrightness → Brightness 当前的亮度模式
no setter
renderObject RenderSliverPinnedPersistentHeader
The underlying RenderObject for this element.
no setteroverride
renderObjectAttachingChild Element?
Returns the child of this Element that will insert a RenderObject into an ancestor of this Element to construct the render tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showNavBar bool

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

True if width be larger than 800
no setter
size Size?
The size of the RenderBox returned by findRenderObject.
no setterinherited
slot Object?
Information set by parent to define where this child fits in its parent's child list.
no setterinherited
statusBarHeight double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

获取状态栏高度
no setter
tabBarTheme TabBarTheme

Available on BuildContext, provided by the ExtensionContext extension

no setter
textScaleFactor double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

textScaleFactor → double 每个逻辑像素的字体像素数
no setter
textTheme TextTheme

Available on BuildContext, provided by the ExtensionContext extension

similar to MediaQuery.of(context).padding
no setter
theme ThemeData

Available on BuildContext, provided by the ExtensionContext extension

similar to MediaQuery.of(context).padding
no setter
userGestureInProgress bool

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

userGestureInProgress
no setter
view FlutterView

Available on BuildContext, provided by the ExtensionContext extension

Returns the FlutterView that the provided context will render into.
no setter
viewInsets EdgeInsets

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

viewInsets → EdgeInsets 显示器的各个部分完全被系统UI遮挡,通常是设备的键盘
no setter
viewPadding EdgeInsets

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

viewPadding → EdgeInsets 显示器的部分被系统UI部分遮挡,通常由硬件显示“凹槽”或系统状态栏
no setter
widget SliverPinnedPersistentHeaderRenderObjectWidget
The configuration for this element.
no setteroverride
width double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

The same of MediaQuery.of(context).size.width Note: updates when you rezise your screen (like on a browser or desktop window)
no setter
widthPixel double

Available on BuildContext, provided by the ExtensionContextWithMediaQuery extension

手机屏幕的宽分辨率
no setter

Methods

activate() → void
Transition from the "inactive" to the "active" lifecycle state.
inherited
addListener(VoidCallback listener) → void

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

attach(BuildContext? context, {FocusOnKeyEventCallback? onKeyEvent, FocusOnKeyCallback? onKey}) FocusAttachment

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

attachNotificationTree() → void
Called in Element.mount and Element.activate to register this element in the notification tree.
inherited
attachRenderObject(Object? newSlot) → void
Add renderObject to the render tree at the location specified by newSlot.
inherited
autofocus([FocusNode? focusNode]) → void

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

自动获取焦点
build(double shrinkOffset, double? minExtent, double maxExtent, bool overlapsContent) → void
canPop() bool

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

canPop
deactivate() → void
Transition from the "active" to the "inactive" lifecycle state.
inherited
deactivateChild(Element child) → void
Move the given element to the list of inactive elements and detach its render object from the render tree.
inherited
debugDeactivated() → void
Called, in debug mode, after children have been deactivated (see deactivate).
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugExpectsRenderObjectForSlot(Object? slot) bool
Whether the child in the provided slot (or one of its descendants) must insert a RenderObject into its ancestor RenderObjectElement by calling RenderObjectElement.insertRenderObjectChild on it.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
debugGetCreatorChain(int limit) String
Returns a description of what caused this element to be created.
inherited
debugGetDiagnosticChain() List<Element>
Returns the parent chain from this element back to the root of the tree.
inherited
debugVisitOnstageChildren(ElementVisitor visitor) → void
Calls the argument for each child considered onstage.
inherited
dependOnInheritedElement(InheritedElement ancestor, {Object? aspect}) InheritedWidget
Registers this build context with ancestor such that when ancestor's widget changes this build context is rebuilt.
inherited
dependOnInheritedWidgetOfExactType<T extends InheritedWidget>({Object? aspect}) → T?
Returns the nearest widget of the given type T and creates a dependency on it, or null if no appropriate widget is found.
inherited
describeElement(String name, {DiagnosticsTreeStyle style = DiagnosticsTreeStyle.errorProperty}) DiagnosticsNode
Returns a description of the Element associated with the current build context.
inherited
describeMissingAncestor({required Type expectedAncestorType}) List<DiagnosticsNode>
Adds a description of a specific type of widget missing from the current build context's ancestry tree.
inherited
describeOwnershipChain(String name) DiagnosticsNode
Adds a description of the ownership chain from a specific Element to the error report.
inherited
describeWidget(String name, {DiagnosticsTreeStyle style = DiagnosticsTreeStyle.errorProperty}) DiagnosticsNode
Returns a description of the Widget associated with the current build context.
inherited
detachRenderObject() → void
Remove renderObject from the render tree.
inherited
didChangeDependencies() → void
Called when a dependency of this element changes.
inherited
dispatchNotification(Notification notification) → void
Start bubbling this notification at the given build context.
inherited
doesDependOnInheritedElement(InheritedElement ancestor) bool
Returns true if dependOnInheritedElement was previously called with ancestor.
inherited
findAncestorRenderObjectOfType<T extends RenderObject>() → T?
Returns the RenderObject object of the nearest ancestor RenderObjectWidget widget that is an instance of the given type T.
inherited
findAncestorStateOfType<T extends State<StatefulWidget>>() → T?
Returns the State object of the nearest ancestor StatefulWidget widget that is an instance of the given type T.
inherited
findAncestorWidgetOfExactType<T extends Widget>() → T?
Returns the nearest ancestor widget of the given type T, which must be the type of a concrete Widget subclass.
inherited
findRenderObject() RenderObject?
The current RenderObject for the widget. If the widget is a RenderObjectWidget, this is the render object that the widget created for itself. Otherwise, it is the render object of the first descendant RenderObjectWidget.
inherited
findRootAncestorStateOfType<T extends State<StatefulWidget>>() → T?
Returns the State object of the furthest ancestor StatefulWidget widget that is an instance of the given type T.
inherited
focusInDirection(TraversalDirection direction) bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

forgetChild(Element child) → void
Remove the given child from the element's child list, in preparation for the child being reused elsewhere in the element tree.
override
getElementForInheritedWidgetOfExactType<T extends InheritedWidget>() InheritedElement?
Obtains the element corresponding to the nearest widget of the given type T, which must be the type of a concrete InheritedWidget subclass.
inherited
getInheritedWidgetOfExactType<T extends InheritedWidget>() → T?
Returns the nearest widget of the given InheritedWidget subclass T or null if an appropriate ancestor is not found.
inherited
getWidgetGlobalToLocal({Offset point = Offset.zero, RenderObject? ancestor}) Offset

Available on BuildContext, provided by the ExtensionContext extension

Get the coordinates of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的坐标,widget必须渲染完成
getWidgetLocalToGlobal({Offset point = Offset.zero, RenderObject? ancestor}) Offset

Available on BuildContext, provided by the ExtensionContext extension

Get the coordinates of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的坐标,widget必须渲染完成
getWidgetRectGlobalToLocal({Offset point = Offset.zero, RenderObject? ancestor}) Rect?

Available on BuildContext, provided by the ExtensionContext extension

Get the Rect of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的Rect,widget必须渲染完成
getWidgetRectLocalToGlobal({Offset point = Offset.zero, RenderObject? ancestor}) Rect?

Available on BuildContext, provided by the ExtensionContext extension

Get the Rect of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的Rect,widget必须渲染完成
heightTransformer({double dividedBy = 1, double reducedBy = 0.0}) double

Available on BuildContext, provided by the ExtensionContext extension

Gives you the power to get a portion of the height. Useful for responsive applications.
inflateWidget(Widget newWidget, Object? newSlot) Element
Create an element for the given widget and add it as a child of this element in the given slot.
inherited
insertRenderObjectChild(covariant RenderObject child, covariant dynamic slot) → void
Insert the given child into renderObject at the given slot.
override
markNeedsBuild() → void
Marks the element as dirty and adds it to the global list of widgets to rebuild in the next frame.
inherited
maybePop<T extends Object?>([T? result]) Future<bool>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

maybePop
mount(Element? parent, dynamic newSlot) → void
Add this element to the tree in the given slot of the given parent.
override
moveRenderObjectChild(covariant RenderObject child, covariant dynamic oldSlot, covariant dynamic newSlot) → void
Move the given child from the given old slot to the given new slot.
override
nextFocus() bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performRebuild() → void
Cause the widget to update itself.
override
pop<T extends Object?>([T? result]) → void

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

pop
popAndPushNamed<T extends Object?, TO extends Object?>(String routeName, {TO? result, Object? arguments}) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

popAndPushNamed
popUntil(RoutePredicate predicate) → void

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

popUntil
previousFocus() bool

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

push<T extends Object?>(Route<T> route) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

push
pushAndRemoveUntil<T extends Object?>(Route<T> newRoute, RoutePredicate predicate) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

pushAndRemoveUntil
pushNamed<T extends Object?>(String routeName, {Object? arguments}) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

pushNamed
pushNamedAndRemoveUntil<T extends Object?>(String newRouteName, RoutePredicate predicate, {Object? arguments}) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

pushNamedAndRemoveUntil
pushReplacement<T extends Object?, TO extends Object?>(Route<T> newRoute, {TO? result}) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

pushReplacement
pushReplacementNamed<T extends Object?, TO extends Object?>(String routeName, {TO? result, Object? arguments}) Future<T?>

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

pushReplacementNamed
ratio({double dividedBy = 1, double reducedByW = 0.0, double reducedByH = 0.0}) double

Available on BuildContext, provided by the ExtensionContext extension

Divide the height proportionally by the given value
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
rebuild({bool force = false}) → void
Cause the widget to update itself. In debug builds, also verify various invariants.
inherited
removeListener(VoidCallback listener) → void

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

removeRenderObjectChild(covariant RenderObject child, covariant dynamic slot) → void
Remove the given child from renderObject.
override
removeRoute(Route route) → void

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

removeRoute
removeRouteBelow(Route route) → void

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

removeRouteBelow
requestFocus([FocusNode? focusNode]) → void

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

focusNode==null 移出焦点 (可用于关闭键盘) focusNode!!= null 获取焦点
restorablePopAndPushNamed<T extends Object?, TO extends Object?>(String routeName, {TO? result, Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorablePopAndPushNamed
restorablePush<T extends Object?>(RestorableRouteBuilder<T> routeBuilder, {Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorablePush
restorablePushNamed<T extends Object?>(String routeName, {Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorablePushNamed
restorablePushNamedAndRemoveUntil<T extends Object?>(String newRouteName, RoutePredicate predicate, {Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorablePushNamedAndRemoveUntil
restorablePushReplacement<T extends Object?, TO extends Object?>(RestorableRouteBuilder<T> routeBuilder, {TO? result, Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorablePushReplacement
restorablePushReplacementNamed<T extends Object?, TO extends Object?>(String routeName, {TO? result, Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorablePushReplacementNamed
restorableReplace<T extends Object?>({required Route oldRoute, required RestorableRouteBuilder<T> newRouteBuilder, Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorableReplace
restorableReplaceRouteBelow<T extends Object?>({required Route anchorRoute, required RestorableRouteBuilder<T> newRouteBuilder, Object? arguments}) String

Available on BuildContext, provided by the ExtensionNavigatorStateContext extension

restorableReplaceRouteBelow
setFirstFocus(FocusScopeNode scope) → void

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this element.
inherited
unfocus({UnfocusDisposition disposition = UnfocusDisposition.scope}) → void

Available on BuildContext, provided by the ExtensionFocusScopeContext extension

unmount() → void
Transition from the "inactive" to the "defunct" lifecycle state.
override
update(covariant SliverPinnedPersistentHeaderRenderObjectWidget newWidget) → void
Change the widget used to configure this element.
override
updateChild(Element? child, Widget? newWidget, Object? newSlot) Element?
Update the given child with the given new configuration.
inherited
updateChildren(List<Element> oldChildren, List<Widget> newWidgets, {Set<Element>? forgottenChildren, List<Object?>? slots}) List<Element>
Updates the children of this element to use new widgets.
inherited
updateSlot(Object? newSlot) → void
Called by updateSlotForChild when the framework needs to change the slot that this Element occupies in its ancestor.
inherited
updateSlotForChild(Element child, Object? newSlot) → void
Change the slot that the given child occupies in its parent.
inherited
visitAncestorElements(ConditionalElementVisitor visitor) → void
Walks the ancestor chain, starting with the parent of this build context's widget, invoking the argument for each ancestor.
inherited
visitChildElements(ElementVisitor visitor) → void
Wrapper around visitChildren for BuildContext.
inherited
visitChildren(ElementVisitor visitor) → void
Calls the argument for each child. Must be overridden by subclasses that support having children.
override
widthTransformer({double dividedBy = 1, double reducedBy = 0.0}) double

Available on BuildContext, provided by the ExtensionContext extension

Gives you the power to get a portion of the width. Useful for responsive applications.

Operators

operator ==(Object other) bool
Compare two widgets for equality.
inherited