TextInputLimitFormatter enum

Inheritance
Available extensions

Values

lettersNumbers → const TextInputLimitFormatter

字母和数字

const TextInputLimitFormatter('[a-zA-Z0-9]')
password → const TextInputLimitFormatter

密码 字母和数字和.

const TextInputLimitFormatter('[a-zA-Z0-9.]')
number → const TextInputLimitFormatter

整数

const TextInputLimitFormatter('[0-9]')
text → const TextInputLimitFormatter

文本

const TextInputLimitFormatter('')
decimal → const TextInputLimitFormatter

小数

const TextInputLimitFormatter('[0-9.]')
letter → const TextInputLimitFormatter

字母

const TextInputLimitFormatter('[a-zA-Z]')
chinese → const TextInputLimitFormatter

中文

const TextInputLimitFormatter('[\u4e00-\u9fa5]')
email → const TextInputLimitFormatter

邮箱

const TextInputLimitFormatter('[a-zA-Z0-9.@]')
phone → const TextInputLimitFormatter

电话号码

const TextInputLimitFormatter('[0-9-+]')
idCard → const TextInputLimitFormatter

身份证

const TextInputLimitFormatter('[0-9Xx]')
positive → const TextInputLimitFormatter

正数

const TextInputLimitFormatter('[+0-9.]')
negative → const TextInputLimitFormatter

负数

const TextInputLimitFormatter('[-0-9.]')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
regExp String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toKeyboardType() TextInputType
TextInputLimitFormatter 转换为 TextInputType
toString() String
A string representation of this object.
inherited
toTextInputFormatter() List<TextInputFormatter>
TextInputLimitFormatter 转换为 List

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TextInputLimitFormatter>
A constant List of the values in this enum, in order of their declaration.