RoutePushStyle enum
- Inheritance
- Available extensions
Values
- cupertino → const RoutePushStyle
-
Cupertino风格
- material → const RoutePushStyle
-
Material风格
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pageRoute<
T> ({WidgetBuilder? builder, Widget? widget, bool maintainState = true, bool fullscreenDialog = false, String? title, RouteSettings? settings}) → PageRoute< T> -
Available on RoutePushStyle, provided by the ExtensionRoutePushStyle extension
Builds the primary contents of the route. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RoutePushStyle> - A constant List of the values in this enum, in order of their declaration.