ExtensionContext extension

on

Properties

getRenderBox RenderBox?

Available on BuildContext, provided by the ExtensionContext extension

no setter
getWidgetBounds Rect

Available on BuildContext, provided by the ExtensionContext extension

get Widget Bounds (width, height, left, top, right, bottom and so on).Widgets must be rendered completely. 获取widget Rect
no setter
iconButtonTheme IconButtonThemeData

Available on BuildContext, provided by the ExtensionContext extension

no setter
iconColor Color?

Available on BuildContext, provided by the ExtensionContext extension

give access to Theme.of(context).iconTheme.color
no setter
iconTheme IconThemeData

Available on BuildContext, provided by the ExtensionContext extension

no setter
isDarkMode bool

Available on BuildContext, provided by the ExtensionContext extension

Check if dark mode theme is enable
no setter
maybeOverlay OverlayState?

Available on BuildContext, provided by the ExtensionContext extension

no setter
maybeView FlutterView?

Available on BuildContext, provided by the ExtensionContext extension

Returns the FlutterView that the provided context will render into.
no setter
overlay OverlayState?

Available on BuildContext, provided by the ExtensionContext extension

no setter
tabBarTheme TabBarTheme

Available on BuildContext, provided by the ExtensionContext extension

no setter
textTheme TextTheme

Available on BuildContext, provided by the ExtensionContext extension

similar to MediaQuery.of(context).padding
no setter
theme ThemeData

Available on BuildContext, provided by the ExtensionContext extension

similar to MediaQuery.of(context).padding
no setter
view FlutterView

Available on BuildContext, provided by the ExtensionContext extension

Returns the FlutterView that the provided context will render into.
no setter

Methods

getWidgetGlobalToLocal({Offset point = Offset.zero, RenderObject? ancestor}) Offset

Available on BuildContext, provided by the ExtensionContext extension

Get the coordinates of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的坐标,widget必须渲染完成
getWidgetLocalToGlobal({Offset point = Offset.zero, RenderObject? ancestor}) Offset

Available on BuildContext, provided by the ExtensionContext extension

Get the coordinates of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的坐标,widget必须渲染完成
getWidgetRectGlobalToLocal({Offset point = Offset.zero, RenderObject? ancestor}) Rect?

Available on BuildContext, provided by the ExtensionContext extension

Get the Rect of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的Rect,widget必须渲染完成
getWidgetRectLocalToGlobal({Offset point = Offset.zero, RenderObject? ancestor}) Rect?

Available on BuildContext, provided by the ExtensionContext extension

Get the Rect of the widget on the screen.Widgets must be rendered completely. 获取widget在屏幕上的Rect,widget必须渲染完成
heightTransformer({double dividedBy = 1, double reducedBy = 0.0}) double

Available on BuildContext, provided by the ExtensionContext extension

Gives you the power to get a portion of the height. Useful for responsive applications.
ratio({double dividedBy = 1, double reducedByW = 0.0, double reducedByH = 0.0}) double

Available on BuildContext, provided by the ExtensionContext extension

Divide the height proportionally by the given value
widthTransformer({double dividedBy = 1, double reducedBy = 0.0}) double

Available on BuildContext, provided by the ExtensionContext extension

Gives you the power to get a portion of the width. Useful for responsive applications.