ExtendedResponse<T> class
- Inheritance
- Available extensions
Constructors
-
ExtendedResponse({T? data, int? statusCode, String? statusMessage, Headers? headers, required RequestOptions requestOptions, List<
RedirectRecord> redirects = const [], Map<String, dynamic> ? extra, bool isRedirect = false, Object? error, String? type})
Properties
-
保存的cookie
getter/setter pair
- data ↔ T?
-
The response payload in specific type.
getter/setter pairinherited
- error ↔ Object?
-
error 信息
getter/setter pair
-
extra
↔ Map<
String, dynamic> -
An extra map that you can save your custom information in.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers ↔ Headers
-
Headers for the response.
getter/setter pairinherited
- isRedirect ↔ bool
-
Whether the response has been redirected.
getter/setter pairinherited
- realUri → Uri
-
Return the final real request URI (may be redirected).
no setterinherited
-
redirects
↔ List<
RedirectRecord> -
All redirections happened before the response respond.
getter/setter pairinherited
- requestOptions ↔ RequestOptions
-
The RequestOptions used for the corresponding request.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int?
-
The HTTP status code for the response.
getter/setter pairinherited
- statusMessage ↔ String?
-
Returns the reason phrase associated with the status code.
getter/setter pairinherited
- type ↔ String?
-
请求返回类型 DioException.toString
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toExtendedResponse<
T> () → ExtendedResponse< T> -
Available on Response, provided by the ExtensionResponse extension
-
toMap(
) → Map< String, dynamic> -
Available on ExtendedResponse, provided by the ExtensionExtendedResponse extension
-
toMap(
) → Map< String, dynamic> -
Available on Response, provided by the ExtensionResponse extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generalExtendedResponse<
T> ({dynamic error}) → ExtendedResponse< T> -
mergeError<
T> (DioException err) → ExtendedResponse< T>