ToastStyle enum
Toast类型
如果使用custom 请设置 customIcon
- Inheritance
- Available extensions
Values
- success → const ToastStyle
- fail → const ToastStyle
- info → const ToastStyle
- warning → const ToastStyle
- smile → const ToastStyle
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → IconData
-
Available on ToastStyle, provided by the ExtensionToastStyle extension
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
String message, {IconData? customIcon, ToastOptions? options}) → Future< ExtendedOverlayEntry?> -
Available on ToastStyle, provided by the ExtensionToastStyle extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ToastStyle> - A constant List of the values in this enum, in order of their declaration.