BText class
- Inheritance
- Available extensions
Constructors
-
BText(String text, {Key? key, GestureRecognizer? recognizer, String? semanticsLabel, StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, int? maxLines, TextWidthBasis? textWidthBasis, TextStyle? style, bool inherit = true, Color? color, Color? backgroundColor, String? fontFamily, List<
String> ? fontFamilyFallback, String? package, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, Paint? foreground, Paint? background, TextDecoration decoration = TextDecoration.none, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, String? debugLabel, List<Shadow> ? shadows, List<FontFeature> ? fontFeatures, TextHeightBehavior? textHeightBehavior, Color? selectionColor}) -
const
-
BText.rich({Key? key, required List<
String> texts, TextStyle? style, List<TextStyle> styles = const [], List<GestureRecognizer?> recognizers = const [], List<String> semanticsLabels = const [], StrutStyle? strutStyle, TextAlign? textAlign, TextDirection? textDirection, Locale? locale, bool? softWrap, TextOverflow? overflow, double? textScaleFactor, int? maxLines, TextWidthBasis? textWidthBasis, TextHeightBehavior? textHeightBehavior, bool inherit = true, Color? color, Color? backgroundColor, String? fontFamily, List<String> ? fontFamilyFallback, String? package, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, Paint? foreground, Paint? background, TextDecoration decoration = TextDecoration.none, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, String? debugLabel, List<Shadow> ? shadows, List<FontFeature> ? fontFeatures, Color? selectionColor}) -
与 RText 一致,仅增加 主题适配
const
Properties
- background → Paint?
-
text的背景色
final
- backgroundColor → Color?
-
final
- color → Color?
-
字体颜色,注意: 如果有特殊的foreground,此值必须是null
final
- debugLabel → String?
-
只在调试的使用
final
- decoration → TextDecoration
-
text的划线
TextDecoration.none 没有 默认
TextDecoration.underline 下划线
TextDecoration.overline 上划线
TextDecoration.lineThrough 中间的线(删除线)
final
- decorationColor → Color?
-
decoration划线的颜色
final
- decorationStyle → TextDecorationStyle?
-
decoration划线的样式
TextDecorationStyle.solid实线
TextDecorationStyle.double 画两条线
TextDecorationStyle.dotted 点线(一个点一个点的)
TextDecorationStyle.dashed 虚线(一个长方形一个长方形的线)
TextDecorationStyle.wavy 正玄曲线
final
- decorationThickness → double?
-
final
- expand → SizedBox
-
Available on Widget, provided by the ExtensionWidget extension
no setter - expandedNull → Expanded
-
Available on Widget, provided by the ExtensionWidget extension
no setter - fontFamily → String?
-
final
-
fontFamilyFallback
→ List<
String> ? -
final
-
fontFeatures
→ List<
FontFeature> ? -
final
- fontSize → double?
-
字体大小 默认的是 14
final
- fontStyle → FontStyle?
-
FontStyle.normal正常 FontStyle.italic斜体
final
- fontWeight → FontWeight?
-
字体的粗细程度 FontWeight.w100 -- FontWeight.w900 . 默认是FontWeight.w400,
final
- foreground → Paint?
-
text的前景色,与 color 不能同时设置
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
文本的高度 主要用于TextSpan 来设置不同的高度
final
- inherit → bool
-
TextStyle 以下是字体样式
默认样式会继承层级最为接近的 DefaultTextStyle,为true 表示继承,false 表示完全重写
final
- isRich → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- letterSpacing → double?
-
单个字母或者汉字的距离,默认是1.0,负数可以拉近距离
final
- locale → Locale?
-
Locale,当相同的Unicode字符可以根据不同的地区以不同的方式呈现时,用于选择字体
final
- maxLines → int?
-
int 设置文字的最大展示行数
final
- overflow → TextOverflow?
-
TextOverflow,内容溢出时的处理方式
final
- package → String?
-
final
- recognizer → GestureRecognizer?
-
text手势
final
-
recognizers
→ List<
GestureRecognizer?> -
texts内手势
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionColor → Color?
-
The color to use when painting the selection.
final
- semanticsLabel → String?
-
text语义 - 语义描述标签,相当于此text的别名
final
-
semanticsLabels
→ List<
String> -
texts内语义 - 语义描述标签,相当于此text的别名
final
-
shadows
→ List<
Shadow> ? -
将在text下方绘制的阴影列表
final
- shrink → SizedBox
-
Available on Widget, provided by the ExtensionWidget extension
no setter - softWrap → bool?
-
bool 文本是否应在软换行时断行
final
- strutStyle → StrutStyle?
-
StrutStyle,影响Text在垂直方向上的布局
final
- style → TextStyle?
-
使劲此参数 以下单独字体样式无效
final
-
styles
→ List<
TextStyle> -
texts内样式
final
- text → String
-
final
- textAlign → TextAlign?
-
TextAlign,内容对齐方式
final
- textBaseline → TextBaseline?
-
TextBaseline.ideographic用来对齐表意文字的水平线
TextBaseline.alphabetic 以标准的字母顺序为基线
final
- textDirection → TextDirection?
-
TextDirection,内容的走向方式
final
- textHeightBehavior → TextHeightBehavior?
-
final
-
texts
→ List<
String> -
排在第一个text后面
final
- textScaleFactor → double?
-
double 设置文字的放大缩小,例如,fontSize=10,this.textScaleFactor=2.0,最终得到的文字大小为10*2.0
final
- textWidthBasis → TextWidthBasis?
-
TextWidthBasis 测量一行或多行文本宽度
final
- toRoutePageBuilder → RoutePageBuilder
-
Available on Widget, provided by the ExtensionWidget extension
no setter - toRouteTransitionsBuilder → RouteTransitionsBuilder
-
Available on Widget, provided by the ExtensionWidget extension
no setter - toSliverBox → Widget
-
Available on Widget, provided by the ExtensionWidget extension
no setter - toWidgetBuilder → WidgetBuilder
-
Available on Widget, provided by the ExtensionWidget extension
no setter - wordSpacing → double?
-
单词之间添加的空间间隔,负数可以拉近距离
final
Methods
-
align(
{Key? key, Alignment alignment = Alignment.center, double? widthFactor, double? heightFactor}) → Align -
Available on Widget, provided by the ExtensionWidget extension
-
animatedAlign(
Duration duration, {Key? key, Alignment alignment = Alignment.center, Curve curve = Curves.linear, VoidCallback? onEnd}) → AnimatedAlign -
Available on Widget, provided by the ExtensionWidget extension
-
animatedContainer(
Duration duration, {Key? key, Alignment? alignment, EdgeInsetsGeometry? padding, Color? color, Decoration? decoration, Decoration? foregroundDecoration, double? width, double? height, BoxConstraints? constraints, EdgeInsetsGeometry? margin, Matrix4? transform, Curve curve = Curves.linear, VoidCallback? onEnd}) → AnimatedContainer -
Available on Widget, provided by the ExtensionWidget extension
-
animatedPadding(
{Key? key, Curve curve = Curves.linear, required Duration duration, required EdgeInsetsGeometry padding, VoidCallback? onEnd}) → AnimatedPadding -
Available on Widget, provided by the ExtensionWidget extension
-
asList(
) → List< Widget> -
Available on Widget, provided by the ExtensionWidget extension
-
backdropFilter(
{Key? key, ImageFilter? filter, double fuzzyDegree = 4}) → BackdropFilter -
Available on Widget, provided by the ExtensionWidget extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
buildPageRoute<
T> ({bool maintainState = true, bool fullscreenDialog = false, String? title, required RoutePushStyle pushStyle, RouteSettings? settings}) → PageRoute< T> -
Available on Widget, provided by the ExtensionWidget extension
-
card(
{Color? color, Color? shadowColor, double? elevation, ShapeBorder? shape, bool? borderOnForeground, EdgeInsetsGeometry? margin, Clip? clipBehavior, bool? semanticContainer}) → Card -
Available on Widget, provided by the ExtensionWidget extension
-
center(
{Key? key, double? widthFactor, double? heightFactor}) → Center -
Available on Widget, provided by the ExtensionWidget extension
-
clipOval(
{Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper< Rect> ? clipper, Clip clipBehavior = Clip.antiAlias}) → ClipOval -
Available on Widget, provided by the ExtensionWidget extension
-
clipPath(
{Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper< Path> ? clipper, Clip clipBehavior = Clip.antiAlias}) → ClipPath -
Available on Widget, provided by the ExtensionWidget extension
-
clipRRect(
{Key? key, BorderRadius borderRadius = BorderRadius.zero, CustomClipper< RRect> ? clipper, Clip clipBehavior = Clip.antiAlias}) → ClipRRect -
Available on Widget, provided by the ExtensionWidget extension
-
color(
Color color, {Key? key}) → ColoredBox -
Available on Widget, provided by the ExtensionWidget extension
-
constrainedBox(
BoxConstraints constraints, {Key? key}) → ConstrainedBox -
Available on Widget, provided by the ExtensionWidget extension
-
container(
{Key? key, EdgeInsetsGeometry? padding, Decoration? foregroundDecoration, Matrix4? transform, BoxConstraints? constraints, Color? color, double? width, double? height, EdgeInsetsGeometry? margin, Decoration? decoration, Clip? clipBehavior, AlignmentGeometry? alignment}) → Container -
Available on Widget, provided by the ExtensionWidget extension
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
override
-
decoratedBox(
Decoration decoration, {Key? key, DecorationPosition position = DecorationPosition.background}) → DecoratedBox -
Available on Widget, provided by the ExtensionWidget extension
-
expanded(
{Key? key, int flex = 1}) → Expanded -
Available on Widget, provided by the ExtensionWidget extension
-
fittedBox(
{Key? key, BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, Clip clipBehavior = Clip.none}) → FittedBox -
Available on Widget, provided by the ExtensionWidget extension
-
flexible(
{Key? key, int flex = 1, FlexFit fit = FlexFit.loose}) → Flexible -
Available on Widget, provided by the ExtensionWidget extension
-
fromSize(
Size size, {Key? key}) → SizedBox -
Available on Widget, provided by the ExtensionWidget extension
-
gestureDetector(
{Key? key, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, GestureTapCallback? onTap, GestureTapCancelCallback? onTapCancel, GestureTapDownCallback? onSecondaryTapDown, GestureTapUpCallback? onSecondaryTapUp, GestureTapCancelCallback? onSecondaryTapCancel, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureLongPressStartCallback? onLongPressStart, GestureLongPressMoveUpdateCallback? onLongPressMoveUpdate, GestureLongPressUpCallback? onLongPressUp, GestureLongPressEndCallback? onLongPressEnd, GestureDragDownCallback? onVerticalDragDown, GestureDragStartCallback? onVerticalDragStart, GestureDragUpdateCallback? onVerticalDragUpdate, GestureDragEndCallback? onVerticalDragEnd, GestureDragCancelCallback? onVerticalDragCancel, GestureDragDownCallback? onHorizontalDragDown, GestureDragStartCallback? onHorizontalDragStart, GestureDragUpdateCallback? onHorizontalDragUpdate, GestureDragEndCallback? onHorizontalDragEnd, GestureDragCancelCallback? onHorizontalDragCancel, GestureForcePressStartCallback? onForcePressStart, GestureForcePressPeakCallback? onForcePressPeak, GestureForcePressUpdateCallback? onForcePressUpdate, GestureForcePressEndCallback? onForcePressEnd, GestureDragDownCallback? onPanDown, GestureDragStartCallback? onPanStart, GestureDragUpdateCallback? onPanUpdate, GestureDragEndCallback? onPanEnd, GestureDragCancelCallback? onPanCancel, GestureScaleStartCallback? onScaleStart, GestureScaleUpdateCallback? onScaleUpdate, GestureScaleEndCallback? onScaleEnd, HitTestBehavior? behavior, bool excludeFromSemantics = false, DragStartBehavior dragStartBehavior = DragStartBehavior.start}) → GestureDetector -
Available on Widget, provided by the ExtensionWidget extension
-
hero(
Object tag, {Key? key, CreateRectTween? createRectTween, HeroFlightShuttleBuilder? flightShuttleBuilder, HeroPlaceholderBuilder? placeholderBuilder, bool transitionOnUserGestures = false}) → Hero -
Available on Widget, provided by the ExtensionWidget extension
-
intoConstrainedBox(
BoxConstraints constraints, {Key? key}) → ConstrainedBox -
Available on Widget, provided by the ExtensionWidget extension
-
limitedBox(
{Key? key, double maxWidth = double.infinity, double maxHeight = double.infinity}) → LimitedBox -
Available on Widget, provided by the ExtensionWidget extension
-
margin(
EdgeInsetsGeometry margin, {Key? key}) → Padding -
Available on Widget, provided by the ExtensionWidget extension
-
marginAll(
double margin) → Widget -
Available on Widget, provided by the ExtensionWidget extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the ExtensionWidget extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the ExtensionWidget extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offstage(
bool offstage, {Key? key}) → Offstage -
Available on Widget, provided by the ExtensionWidget extension
-
onDoubleTap(
GestureTapCallback onDoubleTap, {Key? key}) → GestureDetector -
Available on Widget, provided by the ExtensionWidget extension
-
onLongPress(
GestureLongPressCallback onLongPress, {Key? key}) → GestureDetector -
Available on Widget, provided by the ExtensionWidget extension
-
onTap(
GestureTapCallback? onTap, {Key? key}) → GestureDetector -
Available on Widget, provided by the ExtensionWidget extension
-
overflowBox(
{Key? key, Alignment alignment = Alignment.center, double? minWidth, double? maxWidth, double? minHeight, double? maxHeight}) → OverflowBox -
Available on Widget, provided by the ExtensionWidget extension
-
padding(
EdgeInsetsGeometry padding) → Padding -
Available on Widget, provided by the ExtensionWidget extension
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the ExtensionWidget extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the ExtensionWidget extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the ExtensionWidget extension
-
popupBottomSheet<
T> ({WidgetBuilder? builder, BottomSheetOptions? options}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
showModalBottomSheet 关闭 closePopup() -
popupCupertinoDialog<
T> ({WidgetBuilder? builder, DialogOptions? options}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
Cupertino 风格的 Dialog showCupertinoDialog -
popupCupertinoModal<
T> ({WidgetBuilder? builder, CupertinoModalPopupOptions? options}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
showCupertinoModalPopup 全屏显示 -
popupDialog<
T> ({RoutePageBuilder? builder, DialogOptions? options}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
showGeneralDialog -
popupMaterialDialog<
T> ({WidgetBuilder? builder, DialogOptions? options}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
Material 风格的 Dialog showDialog -
positioned(
{Key? key, double? left, double? top, double? right, double? bottom, double? width, double? height}) → Positioned -
Available on Widget, provided by the ExtensionWidget extension
-
push<
T extends Object?, TO extends Object?> ({bool maintainState = true, bool fullscreenDialog = false, RoutePushStyle pushStyle = RoutePushStyle.material, RouteSettings? settings, bool replacement = false, TO? result}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
push or pushReplacement -
pushAndRemoveUntil<
T extends Object?> ({bool maintainState = true, bool fullscreenDialog = false, RoutePushStyle pushStyle = RoutePushStyle.material, RouteSettings? settings, RoutePredicate? predicate}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
pushAndRemoveUntil -
pushReplacement<
T extends Object?, TO extends Object?> ({bool maintainState = true, bool fullscreenDialog = false, RoutePushStyle pushStyle = RoutePushStyle.material, RouteSettings? settings, TO? result}) → Future< T?> -
Available on Widget, provided by the ExtensionWidgetMethod extension
pushReplacement -
rotatedBox(
int quarterTurns, {Key? key}) → RotatedBox -
Available on Widget, provided by the ExtensionWidget extension
-
setHeight(
double height, {Key? key}) → SizedBox -
Available on Widget, provided by the ExtensionWidget extension
-
setSize(
Size size, {Key? key}) → SizedBox -
Available on Widget, provided by the ExtensionWidget extension
-
setWidth(
double width, {Key? key}) → SizedBox -
Available on Widget, provided by the ExtensionWidget extension
-
showLoading(
{ModalWindowsOptions? options}) → ExtendedOverlayEntry? -
Available on Widget, provided by the ExtensionWidgetMethod extension
ExtendedOverlay().showLoading(this) -
showOverlay(
{bool autoOff = false}) → ExtendedOverlayEntry? -
Available on Widget, provided by the ExtensionWidgetMethod extension
ExtendedOverlay().showOverlay() -
singleChildScrollView(
{Key? key, Axis scrollDirection = Axis.vertical, bool reverse = false, EdgeInsetsGeometry? padding, bool? primary, ScrollPhysics? physics, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start}) → SingleChildScrollView -
Available on Widget, provided by the ExtensionWidget extension
-
sizedBox(
{Key? key, double? width, double? height}) → SizedBox -
Available on Widget, provided by the ExtensionWidget extension
-
sizedOverflowBox(
Size size, {Key? key, Alignment alignment = Alignment.center}) → SizedOverflowBox -
Available on Widget, provided by the ExtensionWidget extension
-
sliverToBoxAdapter(
{Key? key}) → SliverToBoxAdapter -
Available on Widget, provided by the ExtensionWidget extension
-
statusBarStyle(
SystemUiOverlayStyle style) → AnnotatedRegion< SystemUiOverlayStyle> -
Available on Widget, provided by the ExtensionWidget extension
-
toDecoratorEntry(
{DecoratorPositioned positioned = DecoratorPositioned.outer, OverlayVisibilityMode mode = OverlayVisibilityMode.always}) → DecoratorEntry -
Available on Widget, provided by the ExtensionWidget extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
transform(
{Key? key, required Matrix4 transform, Offset? origin, AlignmentGeometry? alignment, bool? transformHitTests}) → Transform -
Available on Widget, provided by the ExtensionWidget extension
-
unconstrainedBox(
{Key? key, TextDirection? textDirection, Alignment alignment = Alignment.center, Axis? constrainedAxis}) → UnconstrainedBox -
Available on Widget, provided by the ExtensionWidget extension
-
visibility(
bool visible, {Key? key}) → Visibility -
Available on Widget, provided by the ExtensionWidget extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited