ExtensionIterableE<E> extension
Utility extension methods for the native Iterable class.
- on
-
- Iterable<
E>
- Iterable<
Methods
-
all(
bool test(E element)) → bool -
Available on Iterable<
Alias for IterableE> , provided by the ExtensionIterableE extension.every. -
builder<
T> (T builder(E)) → List< T> -
Available on Iterable<
Iterable.map.toList()E> , provided by the ExtensionIterableE extension -
containsAll(
Iterable< E> other, {bool collapseDuplicates = true}) → bool -
Available on Iterable<
Returns true if every element inE> , provided by the ExtensionIterableE extensionotheralso exists inthis. -
containsAny(
Iterable< E> other) → bool -
Available on Iterable<
ReturnsE> , provided by the ExtensionIterableE extensiontrueifthiscontains at least one element also contained inother. -
firstOrNullWhere(
bool predicate(E element)) → E? -
Available on Iterable<
Returns the first element matching the givenE> , provided by the ExtensionIterableE extensionpredicate, ornullif no such element was found. -
none(
bool test(E element)) → bool -
Available on Iterable<
ReturnsE> , provided by the ExtensionIterableE extensiontrueif no element ofthissatisfiestest. -
one(
bool test(E element)) → bool -
Available on Iterable<
ReturnsE> , provided by the ExtensionIterableE extensiontrueif there is exactly one element ofthiswhich satisfiestest. -
sum(
num addend(E)) → num -
Available on Iterable<
Returns the sum of all the values in this iterable, as defined byE> , provided by the ExtensionIterableE extensionaddend.