FlIndicator class
指示器
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlIndicator
- Available extensions
Constructors
Properties
- activeColor → Color?
-
active color
final
- activeSize → double
-
final
- color → Color?
-
normal color
final
- count → int
-
count of dots
final
- dropHeight → double
-
Only valid when layout==FlIndicatorStyle.drop
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- position → double
-
usually use
pageController.pagefinal - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
Only valid when layout==FlIndicatorStyle.scale
final
- size → double
-
size of the dots
final
- space → double
-
space between dots.
final
- style → FlIndicatorStyle
-
layout of the dots,default is FlIndicatorStyle.slide
final
- toExpansionTilesRotationIconBuilder → ExpansionTilesRotationIconBuilder
-
Available on Widget, provided by the ExtensionExpansionTiles extension
no setter - toToggleRotateIconBuilder → ToggleRotateIconBuilder
-
Available on Widget, provided by the ExtensionWidgetToggleRotate extension
no setter
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
createPainter(
Color activeColor, Color color) → FlIndicatorPainter -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDecoratorPendant<
T> ({DecoratorPendantPosition positioned = DecoratorPendantPosition.outer, bool maintainSize = false, bool? needFocus, bool? needEditing, DecoratorPendantValueCallback< T?> ? needValue}) → DecoratorPendant<T> -
Available on Widget, provided by the ExtensionWidgetDecoratorBox extension
-
toDecoratorPendantBuilder<
T> ({DecoratorPendantPosition positioned = DecoratorPendantPosition.outer, bool maintainSize = false, bool? needFocus, bool? needEditing, DecoratorPendantValueCallback< T?> ? needValue}) → DecoratorPendant<T> -
Available on Widget, provided by the ExtensionWidgetDecoratorBox extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited